$visioFileName = $PSScriptRoot + "\demo\PdfNote.vsd"
$pdfFileName = $PSScriptRoot + "\demo\PdfNote.pdf"

Write-Host converting $visioFileName to $pdfFileName

# make sure PdfSharp nuget module is installed
Add-Type -Path (Get-ChildItem -Filter PdfSharp.dll -Recurse $PSScriptRoot).FullName

# start Visio and open the document

$visio = New-Object -ComObject Visio.Application
$visio.Visible = $true
$visioDoc = $visio.Documents.Open($visioFileName)

$visioDoc.ExportAsFixedFormat(1, $pdfFileName, 1, 0)

$pdfDoc = [PdfSharp.Pdf.IO.PdfReader]::Open($pdfFileName);

for ($i = 0; $i -lt $pdfDoc.PageCount; $i = $i + 1) {

    $pdfPage = $pdfDoc.Pages[$i]
    $visioPage = $visioDoc.Pages[1 + $i]

    foreach ($visioShape in $visioPage.Shapes) {

        $comment = $visioShape.CellsU("Comment").ResultStr(0)
        if ($comment) {

            $x = $visioShape.CellsU("PinX").ResultIU - $visioShape.CellsU("Width").ResultIU / 2
            $y = $visioShape.CellsU("PinY").ResultIU + $visioShape.CellsU("Height").ResultIU / 2

            $annotation = New-Object PdfSharp.Pdf.Annotations.PdfTextAnnotation
            $annotation.Title = $visioShape.Characters.Text
            $annotation.Contents = $comment
            $annotation.Icon = 6

            $point = New-Object PdfSharp.Drawing.XPoint(($x * 72), ($y * 72))
            $size = New-Object PdfSharp.Drawing.XSize(0, 0)
            $rect = New-Object PdfSharp.Drawing.XRect($point, $size)
            $annotation.Rectangle = New-Object PdfSharp.Pdf.PdfRectangle($rect)
            
            $pdfPage.Annotations.Add($annotation)
        }
    }
}

$pdfDoc.Save($pdfFileName);
$visio.Quit();
